Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(364)

Unified Diff: runtime/vm/stub_code_arm.cc

Issue 2719603002: Rename Closure instance field type_arguments_ to instantiator_. (Closed)
Patch Set: work in progress Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/simulator_dbc.cc ('k') | runtime/vm/stub_code_arm64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code_arm.cc
diff --git a/runtime/vm/stub_code_arm.cc b/runtime/vm/stub_code_arm.cc
index e74d38a732d4f73016013ddfcf5c9bfbbb0889c9..982ec58071949ce3067328e2bd20a1811fb2aaec 100644
--- a/runtime/vm/stub_code_arm.cc
+++ b/runtime/vm/stub_code_arm.cc
@@ -1770,9 +1770,10 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
Label loop, found, not_found, next_iteration;
// R2: entry start.
// R3: instance class id.
// R4: instance type arguments.
__ SmiTag(R3);
__ CompareImmediate(R3, Smi::RawValue(kClosureCid));
+ __ ldr(R4, FieldAddress(R0, Closure::instantiator_offset()), EQ);
__ ldr(R3, FieldAddress(R0, Closure::function_offset()), EQ);
// R3: instance class id as Smi or function.
__ Bind(&loop);
@@ -1770,9 +1770,10 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
// R2: entry start.
// R3: instance class id.
- // R4: instance type arguments.
+ // R4: instance type arguments (still null if closure).
__ SmiTag(R3);
__ CompareImmediate(R3, Smi::RawValue(kClosureCid));
« no previous file with comments | « runtime/vm/simulator_dbc.cc ('k') | runtime/vm/stub_code_arm64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698